/*
 * $Id$
 *
 * Copyright (c) 2009 by agentes
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 05.10.2009 by Oli B. (oliver.boehm@agentes.de)
 */

package gdv.xport.satz;

import static gdv.xport.feld.Bezeichner.*;
import gdv.xport.feld.*;


/**
 * @author oliver
 * @since 05.10.2009
 * @version $Revision$
 *
 */
public final class Nachsatz extends Satz {

    private final NumFeld anzahlSaetze = new NumFeld(ANZAHL_SAETZE, 10, 5);
    private final AlphaNumFeld vermittler = new AlphaNumFeld(VERMITTLER, 10, 15);
    private final Betrag gesamtBeitrag = new Betrag(GESAMTBEITRAG, 15, 25);
    private final BetragMitVorzeichen gesamtBeitragBrutto = new BetragMitVorzeichen(
            GESAMTBEITRAG_BRUTTO, 15, 40);
    private final BetragMitVorzeichen gesamtProvisionsBetrag = new BetragMitVorzeichen(
            GESAMTPROVISIONSBETRAG, 15, 55);
    private final BetragMitVorzeichen versicherungsLeistungen = new BetragMitVorzeichen(
            VERSICHERUNGSLEISTUNGEN, 15, 70);
    private final BetragMitVorzeichen schadenbearbeitungsKosten = new BetragMitVorzeichen(
            SCHADENBEARBEITUNGSKOSTEN, 15, 85);

    /**
     * Default-Constructor.
     */
    public Nachsatz() {
        super("9999", 1);
        this.remove(SATZNUMMER);
        this.setUpTeildatensatz();
        this.setAnzahlSaetze(0);
    }

    private void setUpTeildatensatz() {
        add(this.anzahlSaetze);
        add(this.vermittler);
        add(this.gesamtBeitrag);
        add(this.gesamtBeitragBrutto);
        add(this.gesamtProvisionsBetrag);
        add(this.versicherungsLeistungen);
        add(this.schadenbearbeitungsKosten);
        add(new AlphaNumFeld(LEERSTELLEN, 157, 100));
    }

    /**
     * @param n Anzahl der eingeschlossenen Saetze
     */
    public void setAnzahlSaetze(final int n) {
        this.anzahlSaetze.setInhalt(n);
        this.getTeildatensatz(1).add(anzahlSaetze);
    }

    /**
     * @return Anzahl der eingeschlossenen Saetze
     */
    public int getAnzahlSaetze() {
        return this.anzahlSaetze.toInt();
    }

    /**
     * Anzahl der Saetze um 1 erhoehen.
     */
    public void increaseAnzahlSaetze() {
        int n = this.getAnzahlSaetze();
        this.setAnzahlSaetze(n + 1);
    }

    /**
     * @param s Vermittler
     */
    public void setVermittler(final String s) {
        this.vermittler.setInhalt(s);
    }

    /**
     * @return Vermittler
     */
    public String getVermittler() {
        return this.vermittler.getInhalt().trim();
    }

    /**
     * Setzt den Gesamtbeitrag.
     *
     * @param beitrag der neue Gesamtbeitrag
     */
    public void setGesamtBeitrag(final double beitrag) {
        this.gesamtBeitrag.setInhalt(beitrag);
    }

    /**
     * @return Gesamtbeitrag
     */
    public Betrag getGesamtBeitrag() {
        return this.gesamtBeitrag;
    }

    /**
     * @param beitrag neuer Gesamtbeitrag
     */
    public void setGesamtBeitragBrutto(final double beitrag) {
        this.gesamtBeitrag.setInhalt(beitrag);
    }

    /**
     * @return Gesamtbeitrag (Brutto)
     */
    public BetragMitVorzeichen getGesamtBeitragBrutto() {
        return this.gesamtBeitragBrutto;
    }

    /**
     * @param betrag neuer Betrag
     */
    public void setVersicherungsLeistungen(final Double betrag) {
        this.versicherungsLeistungen.setInhalt(betrag);
    }

    /**
     * @return Versichuerungsleistungen
     */
    public BetragMitVorzeichen getVersicherungsLeistungen() {
        return this.versicherungsLeistungen;
    }

    /**
     * @param kosten Kosten der Schadensbearbeitung
     */
    public void setSchadenbearbeitungsKosten(final double kosten) {
        this.schadenbearbeitungsKosten.setInhalt(kosten);
    }

    /**
     * @return Kosten der Schadensbearbeitung
     */
    public BetragMitVorzeichen getSchadenbearbeitungsKosten() {
        return this.schadenbearbeitungsKosten;
    }

}
